==> haskell-diff-0.5-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Diff
version:              0.5
visibility:           public
id:                   Diff-0.5-L7EMQ31ezbBFDqYO9yMkEp
key:                  Diff-0.5-L7EMQ31ezbBFDqYO9yMkEp
license:              BSD-3-Clause
maintainer:           David Fox <dsf@seereason.com>
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  7f55f25782c9ffdf2a012ea5002a581d
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Diff-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-diff
hs-libraries:         HSDiff-0.5-L7EMQ31ezbBFDqYO9yMkEp
depends:              array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-diff-0.5-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Diff
version:              0.5
visibility:           public
id:                   Diff-0.5-HhQaTNERhJmIrCyukvTeRE
key:                  Diff-0.5-HhQaTNERhJmIrCyukvTeRE
license:              BSD-3-Clause
maintainer:           David Fox <dsf@seereason.com>
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  80ec3faf00c81a09db32c3ada6f7f539
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Diff-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-diff
hs-libraries:         HSDiff-0.5-HhQaTNERhJmIrCyukvTeRE
depends:              array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
